Authors
=======


Lead
----

- Derrick Gilland, dgilland@gmail.com, `dgilland@github <https://github.com/dgilland>`_


Contributors
------------

- Bharadwaj Yarlagadda, yarlagaddabharadwaj@gmail.com, `bharadwajyarlagadda@github <https://github.com/bharadwajyarlagadda>`_
